import * as React from 'react';
import { map } from 'ramda';

import Table from '@romanjaros/treejs-components/Table';
import { ITableCol } from '@romanjaros/treejs-components/Table/types';

import { IDocProp } from '../types';


const cols: ITableCol = {
	name: { title: 'Název' },
	type: { title: 'Typ' },
	required: { title: 'Povinný' },
	connect: { title: 'Redux connect' },
	comment: { title: 'Komentář' },
}

interface IProps {
	propDefinition: IDocProp[];
}

const DocTable = (props: IProps): React.ReactElement => {

	const rows: any[] = map(
		(prop: IDocProp) => ({
			name: { title: prop.name },
			type: { title: prop.type },
			required: { title: prop.isOptional ? 'NE' : 'ANO' },
			connect: { title: prop.isConnect ? 'ANO' : 'NE' },
			comment: {
				component: (
					<React.Fragment>
						{prop.comment.split("\n").map((i, key) => <div key={key}>{i}</div>)}
					</React.Fragment>
				)
			}
		})
	)(props.propDefinition)

	return (
		<React.Fragment>
			<Table cols={cols} rows={rows} />
		</React.Fragment>
	);
}

export default DocTable;
