import { find, propEq, prop, map, compose, pathOr, equals, any, cond, pluck, join, head, is } from 'ramda';

import { IDocProp } from '../types';
import { isNilOrEmpty } from '@romanjaros/treejs-utils';


const getType = (type: any) => {
	if (is(Array, type)) {
		return compose(
			join(' | '),
			map((value) => `"${value}"`),
			pluck('value'),
		)(type)
	}

	if (!isNilOrEmpty(type.types)) {
		return compose(
			join(' | '),
			pluck('name')
		)(type.types)
	}

	if (!isNilOrEmpty(type.name)) {
		return type.name;
	}
};

export const generateDocumentationObject = (groups: any[], children: any[]): IDocProp[] => {
	const ids = prop('children', find(propEq('kind', 256))(groups));
	return compose(
		map(
			(child: any) => {
				const shortText = pathOr('', ['comment', 'shortText'], child);
				const text = pathOr('', ['comment', 'text'], child);

				const isConnect = compose(
					any(equals(true)),
					map(propEq('tag', 'connect')),
					pathOr([], ['comment', 'tags']),
				)(child);

				const type = cond([
					[prop('name'), prop('name')],
					[prop('declaration'), compose(
						(definition: any) => {
							const parameters = map(
								(parameter: any) => {
									return `${parameter.name}: ${getType(parameter.type)}`;
								}
							)(definition.parameters || []);
							return `(${join(', ', parameters)}): ${getType(definition.type)}`
						},
						head,
						prop('signatures'),
						prop('declaration'),
					)],
					[prop('types'), compose(
						getType,
						prop('types')
					)],
				])(child.type)

				return {
					name: child.name,
					comment: `${shortText}${text && `\n${text}`}`,
					type: type,
					isOptional: child.flags.isOptional,
					isConnect,
				}
			}
		),
		prop('children'),
		find(propEq('name', 'IProps')),
		map(
			(id) => {
				return find(propEq('id', id))(children)
			}
		),
	)(ids);
}