import * as React from 'react';

import Button from '@romanjaros/treejs-components/Button';
import { Grid, GridCol } from '@romanjaros/treejs-components/Grid';
import { noop } from '@romanjaros/treejs-utils';
import { STATUS } from '@romanjaros/treejs-types/common';

import { generateDocumentationObject } from 'documentation/App/utils/documentation';
import DocTable from 'documentation/App/components/DocTable';

import { groups, children } from '../typedoc.json';

const propDefinition = generateDocumentationObject(groups, children);

const ButtonPage = (): React.ReactElement => {
	return (
		<React.Fragment>
			<h2>Button</h2>

			<h3>Normal</h3>
			<Grid>
				<GridCol size={2}>
					<Button title="Odeslat" onClick={noop} />
				</GridCol>
			</Grid>

			<h3>Status</h3>
			<Grid>
				<GridCol size={2}>
					<Button title="Odeslat" onClick={noop} status={STATUS.info} />
				</GridCol>
				<GridCol size={2}>
					<Button title="Uložit" onClick={noop} status={STATUS.success} />
				</GridCol>
				<GridCol size={2}>
					<Button title="Potvrdit" onClick={noop} status={STATUS.warning} />
				</GridCol>
				<GridCol size={3}>
					<Button title="Zkusit znovu" onClick={noop} status={STATUS.error} />
				</GridCol>
			</Grid>

			<h3>Disable</h3>
			<Grid>
				<GridCol size={2}>
					<Button title="Odeslat" onClick={noop} disabled />
				</GridCol>
			</Grid>

			<h4>Props</h4>
			<DocTable propDefinition={propDefinition} />
		</React.Fragment>
	);
};

export default ButtonPage;
