import * as React from 'react';
import { connect } from 'react-redux';
import { compose } from 'ramda';

import { setAuthenticated } from '@romanjaros/treejs-auth/actions';
import { IAuthOption } from '@romanjaros/treejs-auth/types';
import authRequired, { IAuthHOCInjectProps } from '@romanjaros/treejs-auth/hoc/authRequired';
import Button from '@romanjaros/treejs-components/Button';
import history from 'documentation/App/utils/history';
import { STATUS } from '@romanjaros/treejs-types/common';

import { IAuthPayload } from '../types';


interface IProps extends IAuthHOCInjectProps {
	children: React.ReactElement;
	setAuthenticated: (option: IAuthOption<IAuthPayload>) => void;
}

export class SignOut extends React.Component<IProps> {
	private authenticate = () => {
		this.props.setAuthenticated({
			authenticated: false,
			accessToken: '',
			refreshToken: '',
			userId: null,
		});
		history.push('/signin');
	}

	public render() {
		return (
			<div>
				<Button title="Sign out" status={STATUS.warning} onClick={this.authenticate} />
			</div>
		)
	}
}

export default compose(
	authRequired,
	connect(
		null,
		{ setAuthenticated },
	),
)(SignOut);