import { Middleware } from 'redux';
import { is } from 'ramda';

import { addToaster } from '@romanjaros/treejs-components/Toaster/actions';
import { IAction } from '@romanjaros/treejs-types/redux/actions';
import { isNilOrEmpty, isJSON } from '@romanjaros/treejs-utils';
import { STATUS } from '@romanjaros/treejs-types/common';

import { IFetchConfig } from './types';
import { fetchStatusActions } from './actions';
import { FetchActions } from './constants';
import { resolveParams } from './utils';


interface ISettings {
	BASE_ENDPOINT_URL: string;
}

export const FetchEndpoint = (setting: ISettings): Middleware =>
	(store) => (next) =>
		async (action: IAction<IFetchConfig>) => {
			if (action.type === FetchActions.FETCH) {
				if (isNilOrEmpty(action.payload.url)) {
					throw `URL '${action.payload.url}' is not valid, please specify valid URL!`;
				}

				store.dispatch(fetchStatusActions.beforeRequest(action.payload));

				const endpoint = `${setting.BASE_ENDPOINT_URL}${
					resolveParams(action.payload.url, action.payload.queryParams)
				}`;

				try {
					const response = await fetch(endpoint, {
						headers: {
							'Content-Type': 'application/json',
						},
						method: action.payload.method,
						body: JSON.stringify(action.payload.body),
					});

					store.dispatch(fetchStatusActions.onSuccess(action.payload));

					const json = await response.text().then(function (text) {
						return isJSON(text) ? JSON.parse(text) : {}
					})
					if (is(Function, action.payload.onSuccess)) {
						await action.payload.onSuccess(json);
					}
				} catch (error) {
					store.dispatch(fetchStatusActions.onError(action.payload));
					if (is(Function, action.payload.onError)) {
						action.payload.onError(error);
					} else {
						store.dispatch(
							addToaster({
								name: 'fetchUnexpectedError',
								status: STATUS.error,
								message: 'Nastala neočekávaná chyba při volání serveru',
							})
						);
					}
				}
			}

			return next(action);
		};
