import * as React from 'react';
import { connect } from 'react-redux';

import { isAuthenticated } from '../selectors';


interface IAuthComponent extends IAuthHOCInjectProps{
	isAuthenticate: boolean;
}

export interface IAuthHOCInjectProps {
	isAuthenticate?: boolean;
}

export interface IAuthOptions {
	allowUnauthenticated?: boolean;
}

function authRequired(WrappedComponent: React.ComponentType<IAuthHOCInjectProps>, options: IAuthOptions = {}) {
	class AuthComponent extends React.PureComponent<IAuthComponent> {
		public render() {
			if (this.props.isAuthenticate || options.allowUnauthenticated) {
				return <WrappedComponent {...this.props} />;
			}
			return <div>You are not authenticated, please sign in.</div>;
		}
	}

	return connect(
		(state) => ({
			isAuthenticate: isAuthenticated(state),
		}),
	)(AuthComponent);
}

export default authRequired;