import styled, { css } from '../styled';


export const StyledTopMenu = styled.div`
	height: 40px;

	display: flex;

	background-color: ${(p) => p.theme.white};
	color: ${(p) => p.theme.primaryColor};

	padding: 10px 10px 10px 20px;
`;

export const StyledTopMenuItem = styled.div`
	margin: 10px;
	max-width: 100px;

	cursor: pointer;

	vertical-align: middle;
`;

export const StyledTopMenuDisplayNextItemIcon = styled.div`
	&:hover div {
		display: block;
	}
`;

export const StyledTopMenuDisplayNextItem = styled.div`
	display: none;

	background-color: ${(p) => p.theme.white};

	position: absolute;
	z-index: 1;
`;

export const StyledTopLeftMenuContainer = styled.div`
	display: flex;

	margin-left: auto;
`;

export const StyledTopMenuItemIcon = styled(StyledTopMenuItem)`
	font-size: 22px;
	margin-right: 30px;
	margin-top: 5px;
`;

export const StyledTopMenuItemLogo = styled(StyledTopMenuItemIcon)`
	cursor: default;
`;

export const StyledTopMenuItemHamburger = styled(StyledTopMenuItemIcon)`
	@media only screen and (min-width: ${(p) => p.theme.mediumScreenSize}px) {
		display: none;
	}
`;

export const StyledLeftMenuLogo = styled.div`
	height: 40px;
	margin: 10px;

	font-size: 30px;

	text-align: center;
`;

interface IStyledLeftMenu {
	enableLeftMenu: boolean;
	open: boolean;
}

export const StyledLeftMenu = styled.div<IStyledLeftMenu>`
	background-color: ${(p) => p.theme.primaryColor};
	color: ${(p) => p.theme.secondaryColor};

	display: ${(p) => p.open && p.enableLeftMenu ? 'flex' : 'none'};
	flex-direction: column;
	flex-shrink: 0;

	width: ${(p) => p.open && p.enableLeftMenu && 200}px;

	@media only screen and (min-width: ${(p) => p.theme.mediumScreenSize}px) {
		display: ${(p) => p.open || p.enableLeftMenu ? 'flex' : 'none'};

		width: 200px;
	}
`;

export const StyledLeftMenuItem = styled.div`
	margin-top: 5px;
	margin-left: 10px;
	height: 30px;

	cursor: pointer;
`;

interface IStyledLeftMenuLabel {
	open: boolean;
}

export const StyledLeftMenuLabel = styled.div<IStyledLeftMenuLabel>`
	margin-left: 10px;

	display: inline-block;
	vertical-align: middle;
`;

interface IStyledRightSide {
	enableLeftMenu: boolean;
	open: boolean;
}

export const StyledRightSide = styled.div<IStyledRightSide>`
	width: 100vw;
	min-height: 100vh;

	display: flex;
	flex-direction: column;

	${(p) => p.open && p.enableLeftMenu && css`
		overflow: hidden;
	`};
`;

interface IStyledPageContent {
	enableLeftMenu: boolean;
	open: boolean;
}

export const StyledPageContent = styled.div<IStyledPageContent>`
	padding-left: 20px;
	padding-right: 20px;

	${(p) => p.open && p.enableLeftMenu && css`
		width: calc(100vw + ${p.open && p.enableLeftMenu ? 200 : 0}px);
	`};
`;
