import * as React from 'react';
import { connect } from 'react-redux';

import { STATUS } from '@romanjaros/treejs-types/common';

import Button from '../../Button';

import { addModal } from '../actions';
import { IModalState } from '../types';
import { addModalComponent } from '../utils/registerModal';


interface IProps extends IModalState {
	addModal: (options: IModalState) => void;
	component: React.ReactElement;
	modalTitle: string;
	status?: STATUS;
	title: string;
}

const AddModalButton = (props: IProps): React.ReactElement => {
	const {
		name,
		title,
		modalTitle,
		component,
		width,
		status,
	} = props;

	const handleClick = (): void => {
		props.addModal({ name, title: modalTitle, width });
		addModalComponent(name, component)
	};

	return (
		<Button title={title} onClick={handleClick} status={status} />
	);
};

export default connect(
	null,
	{
		addModal: addModal,
	}
)(AddModalButton);
