import * as React from 'react';
import { is } from 'ramda';

import { StyledInput } from './style';


interface IProps {
	max: number;
	min: number;
	onChange?: (value: number, e: React.ChangeEvent) => void;
	value?: number;
}

interface IState {
	value?: number;
}

export class Slider extends React.Component<IProps, IState> {
	public state = {
		value: this.props.min,
	}

	public componentDidUpdate(prevProps: IProps) {
		if (prevProps.value !== this.props.value) {
			this.setState({
				value: this.props.value,
			})
		}
	}

	private handleChange = (e: React.ChangeEvent<HTMLInputElement>): void => {
		if (is(Number, e.currentTarget.value) || is(String, e.currentTarget.value)) {
			if (this.props.onChange) {
				this.props.onChange(parseInt(e.currentTarget.value), e);
			}

			this.setState({
				value: parseInt(e.currentTarget.value),
			});
		}
	};

	public render() {
		return (
			<React.Fragment>
				<StyledInput
					type="range"
					max={this.props.max}
					min={this.props.min}
					value={this.state.value}
					onChange={this.handleChange}
				/>
				{this.state.value} / {this.props.max}
			</React.Fragment>
		);
	}
}

export default Slider;