import * as React from 'react';
import { isNil } from 'ramda';

import { StyledTable } from './style';
import { ITableCol, ITableRow } from './types';
import TableHeader from './components/TableHeader';
import TableHeaderCell from './components/TableHeaderCell';
import TableRow from './components/TableRow';
import TableCell from './components/TableCell';


interface IProps {
	cols: ITableCol;
	rows: ITableRow[];
}

class Table extends React.PureComponent<IProps> {
	public render() {
		return (
			<StyledTable>
				<TableHeader>
					{
						this.props.cols && Object.keys(this.props.cols).map(
							(c) => (
								<TableHeaderCell key={c}>
									{this.props.cols[c].title}
								</TableHeaderCell>
							)
						)
					}
				</TableHeader>
				{
					this.props.rows && this.props.rows.map(
						(row: ITableRow, r) => (
							<TableRow key={r}>
								{
									Object.keys(this.props.cols).map(
										(c) => (
											<TableCell title={this.props.cols[c].title} key={c}>
												{
													!isNil(row[c].component)
														? row[c].component
														: row[c].title
												}
											</TableCell>
										)
									)
								}
							</TableRow>
						)
					)
				}
			</StyledTable>
		);
	}
}

export default Table;