import { RefObject } from 'react';

import { STATUS } from '@romanjaros/treejs-types/common';

import styled, { css } from '../styled';


interface ITextField {
	noValue: boolean;
	ref: RefObject<HTMLInputElement>;
	status: STATUS;
}

export const StyledContainer = styled.div.attrs({
	className: 'TextFieldContainer',
})`
	position: relative;

	svg {
		cursor: pointer;
	}
`;

export const StyledTextField = styled.input.attrs({
	className: 'RadioButtonField',
}) <ITextField>`
	border: none;
	border-radius: 2px;

	border-left: 2px solid whitesmoke;
	background-color: whitesmoke;

	padding: 10px;

	outline: none !important;
	box-sizing: border-box;

	width: 100%;

	font-weight: 300;
	line-height: 1.3;

	${(p) => p.status === STATUS.error && css`
		border-left: 2px solid ${p.theme.errorColor};
	`}

	&:focus {
		border-left-color: ${(p) => p.theme.focusBackgroundColor};
	}

	&:disabled {
		background-color: transparent;
		border-left-color: ${(p) => p.theme.disableColor};
		${(p) => p.noValue && css`
			border: none;
		`}
	}

	&:read-only {
		cursor: auto;
	}
`;

export const StyledLabel = styled.label`
	font-size: 13px;
	color: ${(p) => p.theme.black};

	display: inline-block;

	padding-bottom: 4px;
`;

export const StyledTextFieldIcon = styled.div`
	position: absolute;
	top: 28px;
	right: 15px;

	color: ${(p) => p.theme.primaryColor};

	font-size: 20px;

	input:disabled + & {
		color: ${(p) => p.theme.gray};

		& svg {
			cursor: auto;
		}
	}
`;
