import * as React from 'react';
import { connect } from 'react-redux';

import { isNilOrEmpty } from '@romanjaros/treejs-utils';

import { Grid, GridCol, HORIZONTAL_ALIGN } from '../../Grid';

import { StyledToaster, StyledToasterContainer } from '../styles/toaster';
import { toasters } from '../selectors';
import { IToasterReducer } from '../types';


interface IProps {
	toasters: IToasterReducer;
}

class Toasters extends React.Component<IProps> {
	public render() {
		const {
			toasters,
		} = this.props;

		if (isNilOrEmpty(toasters)) {
			return null;
		}

		return (
			<StyledToasterContainer>
				<Grid horizontalAlign={HORIZONTAL_ALIGN.CENTER}>
					<GridCol size={4} >
						{
							Object.keys(toasters).map(
								(key) => {
									const toaster = toasters[key];
									return (
										<StyledToaster key={key} status={toaster.status}>
											{toaster.message}
										</StyledToaster>
									);
								}
							)
						}
					</GridCol>
				</Grid>
			</StyledToasterContainer>
		);
	}
}

export default connect(
	(state) => ({
		toasters: toasters(state),
	})
)(Toasters);
