import * as React from 'react';
import { Field as FormikField } from 'formik';

import { IOption } from '@romanjaros/treejs-components/RadioButton/types';

import { FIELD_TYPE } from '../constants';

import TextField, { IProps as ITextFieldProps } from './fields/TextField';
import CheckboxField, { IProps as ICheckboxFieldProps } from './fields/CheckboxField';
import RadioButtonField, { IProps as IRadioButtonFieldProps } from './fields/RadioButtonField';
import SelectBoxField, { IProps as ISelectBoxFieldProps } from './fields/SelectBoxField';
import DatePickerField from './fields/DatePickerField';


type fieldValueTypes = string | IOption | boolean;

interface IProps extends
	ITextFieldProps<fieldValueTypes>,
	IRadioButtonFieldProps<fieldValueTypes>,
	ISelectBoxFieldProps<fieldValueTypes>,
	ICheckboxFieldProps<fieldValueTypes> {
	component: FIELD_TYPE;
	disabled?: boolean;
	error?: string;
	name: string;
}

export class Field extends React.Component<IProps> {
	public static defaultProps = {
		component: FIELD_TYPE.TEXT_FIELD,
		name: 'field',
		title: 'Field',
		options: [] as IOption[],
	};

	public render(): React.ReactElement {
		const {
			component,
			...other
		} = this.props;

		switch (component) {
			case FIELD_TYPE.TEXT_FIELD:
				return (
					<FormikField component={TextField} {...other} />
				);
			case FIELD_TYPE.CHECKBOX:
				return (
					<FormikField component={CheckboxField} {...other} />
				);
			case FIELD_TYPE.RADIO_BUTTON:
				return (
					<FormikField component={RadioButtonField} {...other} />
				);
			case FIELD_TYPE.SELECT_BOX:
				return (
					<FormikField component={SelectBoxField} {...other} />
				);
			case FIELD_TYPE.DATE_PICKER:
				return (
					<FormikField component={DatePickerField} {...other} />
				);
		}

		return null;
	}
}

export default Field;
