import * as React from 'react';
import { FieldProps } from 'formik';
import { is } from 'ramda';

import RadioButtonComponent, { IProps as IRadioButtonProps } from '@romanjaros/treejs-components/RadioButton';
import { IOption } from '@romanjaros/treejs-components/RadioButton/types';

import { StyledCheckboxErrorMessageContainer } from '../../style';


export interface IProps<V = IOption> extends IRadioButtonProps<V> {
	error?: string;
}

interface IAllProps extends IProps, FieldProps {}

const RadioButtonField = (props: IAllProps): React.ReactElement => {
	const {
		field,
		form: {
			setFieldValue,
		},
		title,
		error,
		options,
		horizontal,
		customRender,
		onClick,
	} = props;

	const handleClick = (option: IOption, e: React.MouseEvent<HTMLInputElement>): void => {
		setFieldValue(field.name, option.code);
		if (is(Function, onClick)) {
			onClick(option, e);
		}
	};

	const handleBlur = (_: IOption, e: React.FocusEvent<HTMLInputElement>): void => {
		field.onBlur(e);
	};

	return (
		<div>
			<RadioButtonComponent
				name={field.name}
				title={title}
				value={field.value}
				options={options}
				onClick={handleClick}
				onBlur={handleBlur}
				horizontal={horizontal}
				customRender={customRender}
			/>
			<StyledCheckboxErrorMessageContainer>{error}</StyledCheckboxErrorMessageContainer>
		</div>
	);
};

export default RadioButtonField;
