import * as React from 'react';
import { FieldProps } from 'formik';

import TextFieldComponent, { IProps as ITextFieldProps } from '@romanjaros/treejs-components/TextField';
import { isNilOrEmpty } from '@romanjaros/treejs-utils';
import { STATUS } from '@romanjaros/treejs-types/common';

import { StyledTextFieldErrorMessageContainer } from '../../style';


export interface IProps<V = string> extends ITextFieldProps<V> {
	error?: string;
}

interface IAllProps extends IProps, FieldProps {}

const TextField = (props: IAllProps): React.ReactElement => {
	const {
		field,
		title,
		error,
		disabled,
	} = props;

	const handleChange = (_: string, e: React.ChangeEvent): void => {
		field.onChange(e);
	};

	const handleBlur = (_: string, e: React.FocusEvent): void => {
		field.onBlur(e);
	};

	const status = !isNilOrEmpty(error) && STATUS.error;

	return (
		<div>
			<TextFieldComponent
				name={field.name}
				title={title}
				value={field.value}
				onChange={handleChange}
				onBlur={handleBlur}
				status={status}
				disabled={disabled}
			/>
			{!disabled && <StyledTextFieldErrorMessageContainer>{error}</StyledTextFieldErrorMessageContainer>}
		</div>
	);
};

export default TextField;
